@@ -140,7 +140,7 @@ test -x $wallpaper_prog && wallpaper_entry=$(entry \
     
 [ -d $HOME/.icewm -a -e /usr/share/xsessions/icewm.desktop ] && icewm_entry=$(entry \
     $ICONS/gnome-documents.png \
-    "$EDITOR $HOME/.icewm/preferences $HOME/.icewm/.prefoverrides $HOME/.icewm/keys $HOME/.icewm/startup $HOME/.icewm/toolbar $HOME/.icewm/menu &" \
+    "$EDITOR $HOME/.icewm/winoptions $HOME/.icewm/preferences $HOME/.icewm/prefoverride $HOME/.icewm/keys $HOME/.icewm/startup $HOME/.icewm/toolbar $HOME/.icewm/menu $HOME/.icewm/menu-applications $HOME/.icewm/personal &" \
     $"Edit IceWM Settings")    
 
 [ -d $HOME/.jwm -a -e /usr/share/xsessions/jwm.desktop ] && jwm_entry=$(entry \
@@ -266,7 +266,7 @@ antixautoremove_prog=/usr/local/bin/yad-autoremove
 test -x $antixautoremove_prog && antixautoremove_entry=$(entry \
     $ICONS/debian-logo.png \
     "/usr/local/bin/yad-autoremove &" \
-    $"antiX autoremove")
+    $"Program Remover")
 
 sysvconf_prog=/usr/sbin/sysv-rc-conf
 test -x $sysvconf_prog && sysvconf_entry=$(entry \
